@@ -19,10 +19,13 @@ class GremlinAPIConfig(object):
         self._bearer_expires = None
         self._bearer_timestamp = None
         self._bearer_token = None
+        self._client_cache = {}
         self._company_name = None
         self._http_proxy = False
         self._https_proxy = False
         self._max_bearer_interval = None
+        self._override_blast_radius = None
+        self._override_node_count = None
         self._password = None
         self._team_id = None
         self._user = None
@@ -78,6 +81,17 @@ class GremlinAPIConfig(object):
         self._bearer_token = bearer_token
         return self.bearer_token
 
+    @property
+    def client_cache(self) -> dict:
+        if not self._client_cache:
+            return {}
+        return self._client_cache
+
+    @client_cache.setter
+    def client_cache(self, client_cache: dict) -> dict:
+        self._client_cache = client_cache
+        return self.client_cache
+
     @property
     def company_name(self) -> str:
         """Company Name for login"""
@@ -115,6 +129,28 @@ class GremlinAPIConfig(object):
         self._max_bearer_interval = max_bearer_interval
         return self.max_bearer_interval
 
+    @property
+    def override_blast_radius(self) -> bool:
+        if not self._override_blast_radius:
+            return False
+        return self._override_blast_radius
+
+    @override_blast_radius.setter
+    def override_blast_radius(self, override_blast_radius: bool) -> bool:
+        self._override_blast_radius = override_blast_radius
+        return self.override_blast_radius
+
+    @property
+    def override_node_count(self) -> bool:
+        if not self._override_node_count:
+            return False
+        return self._override_node_count
+    
+    @override_node_count.setter
+    def override_node_count(self, override_node_count: bool) -> bool:
+        self._override_node_count = override_node_count
+        return self.override_node_count     
+
     @property
     def password(self) -> str:
         """Password for login"""
